==> apache-servicecomb-java-chassis-distribution-2.0.0-src.zip: apache-servicecomb-java-chassis-distribution-2.0.0-src/handlers/handler-router/src/test/java/org/apache/servicecomb/router/VersionCompareUtilTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.router;

import org.apache.servicecomb.router.util.VersionCompareUtil;
import org.junit.Assert;
import org.junit.Test;

/**
 * @Author GuoYl123
 * @Date 2019/11/21
 **/
public class VersionCompareUtilTest {

  @Test
  public void testVersion() {
    Assert.assertTrue(VersionCompareUtil.compareVersion("0.0.1", "0.0.0") > 0);
    Assert.assertEquals(0, VersionCompareUtil.compareVersion("0.0.0", "0.0.0"));
    Assert.assertTrue(VersionCompareUtil.compareVersion("0.0.0", "0.0.1") < 0);
    Assert.assertTrue(VersionCompareUtil.compareVersion("0.0.0", "0.0.0.0") < 0);
    Assert.assertTrue(VersionCompareUtil.compareVersion("0.0.1", "0.0.0.0") > 0);
    Assert.assertTrue(VersionCompareUtil.compareVersion("0.0.1", "0.0.0.0") > 0);
  }
}

==> apache-servicecomb-java-chassis-distribution-2.3.5-src.zip: apache-servicecomb-java-chassis-distribution-2.3.5-src/handlers/handler-router/src/test/java/org/apache/servicecomb/router/VersionCompareUtilTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.router;

import org.apache.servicecomb.router.util.VersionCompareUtil;
import org.junit.Assert;
import org.junit.Test;

public class VersionCompareUtilTest {

  @Test
  public void testVersion() {
    Assert.assertTrue(VersionCompareUtil.compareVersion("0.0.1", "0.0.0") > 0);
    Assert.assertEquals(0, VersionCompareUtil.compareVersion("0.0.0", "0.0.0"));
    Assert.assertTrue(VersionCompareUtil.compareVersion("0.0.0", "0.0.1") < 0);
    Assert.assertEquals(0, VersionCompareUtil.compareVersion("0.0.0", "0.0.0.0"));
    Assert.assertTrue(VersionCompareUtil.compareVersion("0.0.1", "0.0.0.0") > 0);
    Assert.assertTrue(VersionCompareUtil.compareVersion("0.0.1", "0.0.0.0") > 0);
  }
}
